gui Package
===========

:mod:`gui` Package
------------------

.. automodule:: stoqlib.gui
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`events` Module
--------------------

.. automodule:: stoqlib.gui.events
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fields` Module
--------------------

.. automodule:: stoqlib.gui.fields
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fiscalprinter` Module
---------------------------

.. automodule:: stoqlib.gui.fiscalprinter
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`interfaces` Module
------------------------

.. automodule:: stoqlib.gui.interfaces
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stockicons` Module
------------------------

.. automodule:: stoqlib.gui.stockicons
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    stoqlib.gui.base
    stoqlib.gui.dialogs
    stoqlib.gui.editors
    stoqlib.gui.search
    stoqlib.gui.slaves
    stoqlib.gui.templates
    stoqlib.gui.test
    stoqlib.gui.wizards

